#!/bin/bash
#------------------------------------------------------------------------------
# This executes as the user 'vagrant', which has full sudo privs.
declare Version=1.0.5

# This bootstraps a new CentOS server:
# * Ensuring that it has current packages.
# * Ensure that it can connect to the Perforce Package Repository.

echo "Running ${0##*/} v$Version."

cd /tmp

# Even though it's a test/demo environment, we don't want any
# ShellShock or Heartbleed or whatnot.
sudo yum update -y
sudo yum install epel-release -y

# Tools required to build Python, P4Python, Perl, P4Perl, etc.
sudo yum groupinstall -y "Development tools"
sudo yum install -y zlib-devel bzip2-devel openssl-devel ncurses-devel sqlite-devel readline-devel tk-devel gdbm-devel db4-devel libpcap-devel xz-devel

# Enable connection to Perforce Package Repository.
echo "Importing public key for Perforce package repository."
rpm --import http://package.perforce.com/perforce.pubkey

echo "Generating /etc/yum.repos.d/perforce.repo."
echo -e "[perforce]\nname=Perforce\nbaseurl=http://package.perforce.com/yum/rhel/7/x86_64/\nenabled=1\ngpgcheck=1" > /tmp/perforce.repo
sudo chown root:root /tmp/perforce.repo
sudo mv /tmp/perforce.repo /etc/yum.repos.d/.
echo "Repo file is:"
sudo cat /etc/yum.repos.d/perforce.repo

exit 0
